package cd.casic.pipeline.dispatch.api;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.pipeline.dispatch.pojo.thirdpartyagent.ThirdPartyBuildInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.http.MediaType;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.*;

/**
 * @author by mianbin
 * @Classname BuildAgentBuildResource
 * @Description TODO
 * @Date 2025/4/8 16:48
 */
@Tag(name = "BUILD_AGENT_BUILD", description = "第三方接入agent资源")
@RestController
@RequestMapping(value = "/buildAgent/agent/thirdPartyAgent", produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
public interface BuildAgentBuildResource {

    @Operation(summary = "尝试启动构建")
    @GetMapping("/startup")
    CommonResult<ThirdPartyBuildInfo> startBuild(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID)
            String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID)
            String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY)
            String secretKey,
            @Parameter(description = "尝试启动构建的类型", required = false)
            @RequestParam("buildType")
            String buildType
    );

    @Operation(summary = "是否更新")
    @GetMapping("/upgrade")
    CommonResult<Boolean> upgrade(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID)
            String projectId,
            @Parameter(description = "Agent ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_ID)
            String agentId,
            @Parameter(description = "秘钥", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_AGENT_SECRET_KEY)
            String secretKey,
            @Parameter(description = "Agent 版本号", required = false)
            @RequestParam("version")
            String version,
            @Parameter(description = "masterAgent 版本号", required = false)
            @RequestParam("masterVersion")
            String masterVersion
    );

    // 由于原 Kotlin 代码中 upgradeNew 方法未完成，这里保留未完成状态
    @Operation(summary = "是否更新NEW")
    @PostMapping("/upgradeNew")
    CommonResult<?> upgradeNew(
            @Parameter(description = "项目ID", required = true)
            @RequestHeader(AUTH_HEADER_DEVOPS_PROJECT_ID)
            String projectId
    );
}
